==> vtk6-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkSpiderPlotActor.java <==
// java wrapper for vtkSpiderPlotActor object
//

package vtk;
import vtk.*;

public class vtkSpiderPlotActor extends vtkActor2D
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetInputData_2(vtkDataObject id0);
  public void SetInputData(vtkDataObject id0)
    { SetInputData_2(id0); }

  private native void SetInputConnection_3(vtkAlgorithmOutput id0);
  public void SetInputConnection(vtkAlgorithmOutput id0)
    { SetInputConnection_3(id0); }

  private native long GetInput_4();
  public vtkDataObject GetInput() {
    long temp = GetInput_4();

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetIndependentVariables_5(int id0);
  public void SetIndependentVariables(int id0)
    { SetIndependentVariables_5(id0); }

  private native int GetIndependentVariablesMinValue_6();
  public int GetIndependentVariablesMinValue()
    { return GetIndependentVariablesMinValue_6(); }

  private native int GetIndependentVariablesMaxValue_7();
  public int GetIndependentVariablesMaxValue()
    { return GetIndependentVariablesMaxValue_7(); }

  private native int GetIndependentVariables_8();
  public int GetIndependentVariables()
    { return GetIndependentVariables_8(); }

  private native void SetIndependentVariablesToColumns_9();
  public void SetIndependentVariablesToColumns()
    { SetIndependentVariablesToColumns_9(); }

  private native void SetIndependentVariablesToRows_10();
  public void SetIndependentVariablesToRows()
    { SetIndependentVariablesToRows_10(); }

  private native void SetTitleVisibility_11(int id0);
  public void SetTitleVisibility(int id0)
    { SetTitleVisibility_11(id0); }

  private native int GetTitleVisibility_12();
  public int GetTitleVisibility()
    { return GetTitleVisibility_12(); }

  private native void TitleVisibilityOn_13();
  public void TitleVisibilityOn()
    { TitleVisibilityOn_13(); }

  private native void TitleVisibilityOff_14();
  public void TitleVisibilityOff()
    { TitleVisibilityOff_14(); }

  private native void SetTitle_15(String id0);
  public void SetTitle(String id0)
    { SetTitle_15(id0); }

  private native String GetTitle_16();
  public String GetTitle()
    { return GetTitle_16(); }

  private native void SetTitleTextProperty_17(vtkTextProperty id0);
  public void SetTitleTextProperty(vtkTextProperty id0)
    { SetTitleTextProperty_17(id0); }

  private native long GetTitleTextProperty_18();
  public vtkTextProperty GetTitleTextProperty() {
    long temp = GetTitleTextProperty_18();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetLabelVisibility_19(int id0);
  public void SetLabelVisibility(int id0)
    { SetLabelVisibility_19(id0); }

  private native int GetLabelVisibility_20();
  public int GetLabelVisibility()
    { return GetLabelVisibility_20(); }

  private native void LabelVisibilityOn_21();
  public void LabelVisibilityOn()
    { LabelVisibilityOn_21(); }

  private native void LabelVisibilityOff_22();
  public void LabelVisibilityOff()
    { LabelVisibilityOff_22(); }

  private native void SetLabelTextProperty_23(vtkTextProperty id0);
  public void SetLabelTextProperty(vtkTextProperty id0)
    { SetLabelTextProperty_23(id0); }

  private native long GetLabelTextProperty_24();
  public vtkTextProperty GetLabelTextProperty() {
    long temp = GetLabelTextProperty_24();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetNumberOfRings_25(int id0);
  public void SetNumberOfRings(int id0)
    { SetNumberOfRings_25(id0); }

  private native int GetNumberOfRingsMinValue_26();
  public int GetNumberOfRingsMinValue()
    { return GetNumberOfRingsMinValue_26(); }

  private native int GetNumberOfRingsMaxValue_27();
  public int GetNumberOfRingsMaxValue()
    { return GetNumberOfRingsMaxValue_27(); }

  private native int GetNumberOfRings_28();
  public int GetNumberOfRings()
    { return GetNumberOfRings_28(); }

  private native void SetAxisLabel_29(int id0,String id1);
  public void SetAxisLabel(int id0,String id1)
    { SetAxisLabel_29(id0,id1); }

  private native String GetAxisLabel_30(int id0);
  public String GetAxisLabel(int id0)
    { return GetAxisLabel_30(id0); }

  private native void SetAxisRange_31(int id0,double id1,double id2);
  public void SetAxisRange(int id0,double id1,double id2)
    { SetAxisRange_31(id0,id1,id2); }

  private native void SetAxisRange_32(int id0,double id1[]);
  public void SetAxisRange(int id0,double id1[])
    { SetAxisRange_32(id0,id1); }

  private native void GetAxisRange_33(int id0,double id1[]);
  public void GetAxisRange(int id0,double id1[])
    { GetAxisRange_33(id0,id1); }

  private native void SetPlotColor_34(int id0,double id1,double id2,double id3);
  public void SetPlotColor(int id0,double id1,double id2,double id3)
    { SetPlotColor_34(id0,id1,id2,id3); }

  private native void SetPlotColor_35(int id0,double id1[]);
  public void SetPlotColor(int id0,double id1[])
    { SetPlotColor_35(id0,id1); }

  private native void SetLegendVisibility_36(int id0);
  public void SetLegendVisibility(int id0)
    { SetLegendVisibility_36(id0); }

  private native int GetLegendVisibility_37();
  public int GetLegendVisibility()
    { return GetLegendVisibility_37(); }

  private native void LegendVisibilityOn_38();
  public void LegendVisibilityOn()
    { LegendVisibilityOn_38(); }

  private native void LegendVisibilityOff_39();
  public void LegendVisibilityOff()
    { LegendVisibilityOff_39(); }

  private native long GetLegendActor_40();
  public vtkLegendBoxActor GetLegendActor() {
    long temp = GetLegendActor_40();

    if (temp == 0) return null;
    return (vtkLegendBoxActor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native int RenderOverlay_41(vtkViewport id0);
  public int RenderOverlay(vtkViewport id0)
    { return RenderOverlay_41(id0); }

  private native int RenderOpaqueGeometry_42(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_42(id0); }

  private native int RenderTranslucentPolygonalGeometry_43(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_43(id0); }

  private native int HasTranslucentPolygonalGeometry_44();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_44(); }

  private native void ReleaseGraphicsResources_45(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_45(id0); }

  public vtkSpiderPlotActor() { super(); }

  public vtkSpiderPlotActor(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-14-aarch64.pkg.tar.xz: vtk/vtkSpiderPlotActor.java <==
// java wrapper for vtkSpiderPlotActor object
//

package vtk;
import vtk.*;

public class vtkSpiderPlotActor extends vtkActor2D
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetInputData_2(vtkDataObject id0);
  public void SetInputData(vtkDataObject id0)
    { SetInputData_2(id0); }

  private native void SetInputConnection_3(vtkAlgorithmOutput id0);
  public void SetInputConnection(vtkAlgorithmOutput id0)
    { SetInputConnection_3(id0); }

  private native long GetInput_4();
  public vtkDataObject GetInput() {
    long temp = GetInput_4();

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetIndependentVariables_5(int id0);
  public void SetIndependentVariables(int id0)
    { SetIndependentVariables_5(id0); }

  private native int GetIndependentVariablesMinValue_6();
  public int GetIndependentVariablesMinValue()
    { return GetIndependentVariablesMinValue_6(); }

  private native int GetIndependentVariablesMaxValue_7();
  public int GetIndependentVariablesMaxValue()
    { return GetIndependentVariablesMaxValue_7(); }

  private native int GetIndependentVariables_8();
  public int GetIndependentVariables()
    { return GetIndependentVariables_8(); }

  private native void SetIndependentVariablesToColumns_9();
  public void SetIndependentVariablesToColumns()
    { SetIndependentVariablesToColumns_9(); }

  private native void SetIndependentVariablesToRows_10();
  public void SetIndependentVariablesToRows()
    { SetIndependentVariablesToRows_10(); }

  private native void SetTitleVisibility_11(int id0);
  public void SetTitleVisibility(int id0)
    { SetTitleVisibility_11(id0); }

  private native int GetTitleVisibility_12();
  public int GetTitleVisibility()
    { return GetTitleVisibility_12(); }

  private native void TitleVisibilityOn_13();
  public void TitleVisibilityOn()
    { TitleVisibilityOn_13(); }

  private native void TitleVisibilityOff_14();
  public void TitleVisibilityOff()
    { TitleVisibilityOff_14(); }

  private native void SetTitle_15(String id0);
  public void SetTitle(String id0)
    { SetTitle_15(id0); }

  private native String GetTitle_16();
  public String GetTitle()
    { return GetTitle_16(); }

  private native void SetTitleTextProperty_17(vtkTextProperty id0);
  public void SetTitleTextProperty(vtkTextProperty id0)
    { SetTitleTextProperty_17(id0); }

  private native long GetTitleTextProperty_18();
  public vtkTextProperty GetTitleTextProperty() {
    long temp = GetTitleTextProperty_18();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetLabelVisibility_19(int id0);
  public void SetLabelVisibility(int id0)
    { SetLabelVisibility_19(id0); }

  private native int GetLabelVisibility_20();
  public int GetLabelVisibility()
    { return GetLabelVisibility_20(); }

  private native void LabelVisibilityOn_21();
  public void LabelVisibilityOn()
    { LabelVisibilityOn_21(); }

  private native void LabelVisibilityOff_22();
  public void LabelVisibilityOff()
    { LabelVisibilityOff_22(); }

  private native void SetLabelTextProperty_23(vtkTextProperty id0);
  public void SetLabelTextProperty(vtkTextProperty id0)
    { SetLabelTextProperty_23(id0); }

  private native long GetLabelTextProperty_24();
  public vtkTextProperty GetLabelTextProperty() {
    long temp = GetLabelTextProperty_24();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetNumberOfRings_25(int id0);
  public void SetNumberOfRings(int id0)
    { SetNumberOfRings_25(id0); }

  private native int GetNumberOfRingsMinValue_26();
  public int GetNumberOfRingsMinValue()
    { return GetNumberOfRingsMinValue_26(); }

  private native int GetNumberOfRingsMaxValue_27();
  public int GetNumberOfRingsMaxValue()
    { return GetNumberOfRingsMaxValue_27(); }

  private native int GetNumberOfRings_28();
  public int GetNumberOfRings()
    { return GetNumberOfRings_28(); }

  private native void SetAxisLabel_29(int id0,String id1);
  public void SetAxisLabel(int id0,String id1)
    { SetAxisLabel_29(id0,id1); }

  private native String GetAxisLabel_30(int id0);
  public String GetAxisLabel(int id0)
    { return GetAxisLabel_30(id0); }

  private native void SetAxisRange_31(int id0,double id1,double id2);
  public void SetAxisRange(int id0,double id1,double id2)
    { SetAxisRange_31(id0,id1,id2); }

  private native void SetAxisRange_32(int id0,double id1[]);
  public void SetAxisRange(int id0,double id1[])
    { SetAxisRange_32(id0,id1); }

  private native void GetAxisRange_33(int id0,double id1[]);
  public void GetAxisRange(int id0,double id1[])
    { GetAxisRange_33(id0,id1); }

  private native void SetPlotColor_34(int id0,double id1,double id2,double id3);
  public void SetPlotColor(int id0,double id1,double id2,double id3)
    { SetPlotColor_34(id0,id1,id2,id3); }

  private native void SetPlotColor_35(int id0,double id1[]);
  public void SetPlotColor(int id0,double id1[])
    { SetPlotColor_35(id0,id1); }

  private native void SetLegendVisibility_36(int id0);
  public void SetLegendVisibility(int id0)
    { SetLegendVisibility_36(id0); }

  private native int GetLegendVisibility_37();
  public int GetLegendVisibility()
    { return GetLegendVisibility_37(); }

  private native void LegendVisibilityOn_38();
  public void LegendVisibilityOn()
    { LegendVisibilityOn_38(); }

  private native void LegendVisibilityOff_39();
  public void LegendVisibilityOff()
    { LegendVisibilityOff_39(); }

  private native long GetLegendActor_40();
  public vtkLegendBoxActor GetLegendActor() {
    long temp = GetLegendActor_40();

    if (temp == 0) return null;
    return (vtkLegendBoxActor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int RenderOverlay_41(vtkViewport id0);
  public int RenderOverlay(vtkViewport id0)
    { return RenderOverlay_41(id0); }

  private native int RenderOpaqueGeometry_42(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_42(id0); }

  private native int RenderTranslucentPolygonalGeometry_43(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_43(id0); }

  private native int HasTranslucentPolygonalGeometry_44();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_44(); }

  private native void ReleaseGraphicsResources_45(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_45(id0); }

  public vtkSpiderPlotActor() { super(); }

  public vtkSpiderPlotActor(long id) { super(id); }
  public native long   VTKInit();

}
